@@ -4,6 +4,7 @@ import os
 import turtle
 import colorsys
 from tkinter import *
+
 def dice():
     import random
 
@@ -78,8 +79,9 @@ def dice():
     p()
 
     a.mainloop()
-def notepad():
-    
+
+def notepad(pdx=30,pdy=2,bgi="lightblue",bgo="lightgreen"):
+    "note pad bolte"
     def c():
         q.delete(1.0,END)
 
@@ -98,14 +100,14 @@ def notepad():
 
     op=Tk()
     op.geometry("1000x750")
-    op.configure(bg="lightgreen")
+    op.configure(bg=bgo)
     s=Scrollbar(op)
     s.pack(side=RIGHT, fill=Y)
     f4=Frame(width=300,height=80,borderwidth=10,bg='#3D59AB')
-    Label(f4, text="Amul shop billing",bg="orange",fg="red",font="lucida 25 bold",anchor='n').pack()
+    Label(f4, text="Note pad with clear button",bg="orange",fg="red",font="lucida 25 bold",anchor='n').pack()
     f4.pack(side=TOP)
-    q=Text(op,width=75,height=23,bg="lightblue",yscrollcommand=s.set,font="lucida 17 bold")
-    q.pack(padx=30,pady=2)
+    q=Text(op,width=75,height=23,bg=bgi,yscrollcommand=s.set,font="lucida 17 bold")
+    q.pack(padx=pdx,pady=pdy)
     cl=Button(op,text='clear screen',fg='red',font="lucida 20 bold",bg='pink',command=c)
     cl.pack(pady=3)
     m=Menu(op)
@@ -380,8 +382,9 @@ def patter3():
 
 
 def all():
+    """ramgui(text="efdwefew",title="wd wd wf defqe",size=30,speed=1000,pdx=30,pdy=60,bgo="white",bgi="#6bfb28",screen="1024x768")"""
     p=("diamond","ramgenrator","csvhelper","BBF","ramgui","i_sort","b_sort"
-       ,"s_sort","b_search","position","mergesort","lineasearch",'pattern 1-10','notepad','dice')
+       ,"s_sort","b_search","position","mergesort","lineasearch",'pattern 1-10','notepad','dice',"cube")
     for i in p:
         print(i)
 class csvhelper:
@@ -606,6 +609,7 @@ def delete():
      os.remove("t.dat")
      os.rename("tem.dat","t.dat")
      h.close()
+
 def update():
      h=open("t.dat","rb+")
      a={}
@@ -676,7 +680,6 @@ def BBF():
             break
 
 
-
     
 
 def diamond(a,v):
@@ -791,11 +794,11 @@ def b_search(a,b,c,d):
         return (b_search(a,b,c,m-1))
 from tkinter import *
 import random
-def ramgui(text,title,bgi,size,speed,pdx,pdy):
-    "arguments = text,title,bgi,size,speed,pdx,pdy"
+def ramgui(text,title,size,speed,pdx,pdy,bgo="white",bgi="#6bfb28",screen="1024x768"):
+    """arguments = text,title,bgi,size,speed,pdx,pdy,bgo=white",bgi="#6bfb28",screen="1024x768"""
     global lable,l4,a4
     a4=Tk()
-    a4.title("project amul page 37")
+    a4.title("We are thankful of ramesh")
     a4.geometry("1024x768")
     a4.configure(bg=bgi)
 ##    t2=("""Amul is best, Amul is an Indian state gvernment
@@ -816,7 +819,7 @@ def ramgui(text,title,bgi,size,speed,pdx,pdy):
     l4.place(x=pdx, y=pdy)
     def lable():
         color = '#'+("%06x" % random.randint(0, 0xFFFFFF))
-        l4.config(text=text, bg="black",fg=(color),font=f"lucida {size} bold")
+        l4.config(text=text, bg=bgo,fg=(color),font=f"lucida {size} bold")
         a4.after(speed, lable)
     lable()
     color = '#'+("%06x" % random.randint(0, 0xFFFFFF))
@@ -849,8 +852,6 @@ def ramgui(text,title,bgi,size,speed,pdx,pdy):
 
 
 
-
-
 
 
 
